@@ -137,6 +137,30 @@ namespace SparkleLib {
         }
 
 
+        public override string [] Warnings {
+            get {
+                SparkleGit git = new SparkleGit (SparkleConfig.DefaultConfig.TmpPath,
+                    "config --global core.excludesfile");
+
+                git.Start ();
+
+                // Reading the standard output HAS to go before
+                // WaitForExit, or it will hang forever on output > 4096 bytes
+                string output = git.StandardOutput.ReadToEnd ().Trim ();
+                git.WaitForExit ();
+
+                if (string.IsNullOrEmpty (output)) {
+                    return null;
+
+                } else {
+                    return new string [] {
+                        string.Format ("You seem to have configured a system ‘gitignore’ file. " +
+                                       "This may interfere with SparkleShare.\n({0})", output)
+                    };
+                }
+            }
+        }
+
         public override void Stop ()
         {
             if (this.git != null) {
@@ -179,9 +203,10 @@ namespace SparkleLib {
         // Add a .gitignore file to the repo
         private void InstallExcludeRules ()
         {
-            string exlude_rules_file_path = SparkleHelpers.CombineMore (
-                this.target_folder, ".git", "info", "exclude");
+            DirectoryInfo info = Directory.CreateDirectory (SparkleHelpers.CombineMore (
+                this.target_folder, ".git", "info"));
 
+            string exlude_rules_file_path = Path.Combine (info.FullName, "exclude");
             TextWriter writer = new StreamWriter (exlude_rules_file_path);
 
                 // gedit and emacs
@@ -214,7 +239,7 @@ namespace SparkleLib {
                 writer.WriteLine ("Thumbs.db");
                 writer.WriteLine ("Desktop.ini");
 
-		// MS Office
+                // MS Office
                 writer.WriteLine ("~*.tmp");
                 writer.WriteLine ("~*.TMP");
                 writer.WriteLine ("*~*.tmp");
