@@ -52,7 +52,7 @@ namespace SparkleLib {
                 // don't have your own. All data needed to connect is hashed and
                 // we don't store any personal information ever
 
-                uri = "tcp://204.62.14.135:1986"; // TODO: announcements.sparkleshare.org
+                uri = "tcp://notifications.sparkleshare.org:1986";
             }
 
             Uri announce_uri = new Uri (uri);
@@ -75,9 +75,6 @@ namespace SparkleLib {
             case "tcp":
                 listeners.Add (new SparkleListenerTcp (announce_uri, folder_identifier));
                 break;
-            case "irc":
-                listeners.Add (new SparkleListenerIrc (announce_uri, folder_identifier));
-                break;
             default:
                 listeners.Add (new SparkleListenerTcp (announce_uri, folder_identifier));
                 break;
