@@ -18,7 +18,6 @@
 using System;
 using System.Drawing;
 using System.IO;
-using System.Text.RegularExpressions;
 using System.Threading;
 
 using MonoMac.Foundation;
@@ -194,30 +193,7 @@ namespace SparkleShare {
         public override void DecidePolicyForNavigation (WebView web_view, NSDictionary action_info,
             NSUrlRequest request, WebFrame frame, NSObject decision_token)
         {
-            string url = request.Url.ToString ();
-            
-            if (url.StartsWith (Path.VolumeSeparatorChar.ToString ())) {
-                string file_path = request.Url.ToString ();
-                file_path = file_path.Replace ("%20", " ");
-
-                NSWorkspace.SharedWorkspace.OpenFile (file_path);
-
-            } else {
-                Regex regex = new Regex (@"(.+)~(.+)~(.+)");
-                Match match = regex.Match (url);
-
-                if (match.Success) {
-                    string folder_name = match.Groups [1].Value;
-                    string revision    = match.Groups [2].Value;
-                    string note        = match.Groups [3].Value;
-
-                    Thread thread = new Thread (new ThreadStart (delegate {
-                        Program.Controller.AddNoteToFolder (folder_name, revision, note);
-                    }));
-
-                    thread.Start ();
-                }
-            }
+            SparkleEventLogController.LinkClicked (request.Url.ToString ());
         }
     }
 }
