@@ -18,6 +18,8 @@
 using System;
 using System.Collections.Generic;
 using System.Diagnostics;
+using System.IO;
+using System.Text.RegularExpressions;
 using System.Threading;
 
 using SparkleLib;
@@ -115,5 +117,29 @@ namespace SparkleShare {
                     UpdateContentEvent (HTML);
             };
         }
+
+
+        public static void LinkClicked (string url)
+        {
+            if (url.StartsWith (Path.VolumeSeparatorChar.ToString ())) {
+                Program.Controller.OpenFile (url);
+
+            } else {
+                Regex regex = new Regex (@"(.+)~(.+)~(.+)");
+                Match match = regex.Match (url);
+
+                if (match.Success) {
+                    string folder_name = match.Groups [1].Value;
+                    string revision    = match.Groups [2].Value;
+                    string note        = match.Groups [3].Value;
+
+                    Thread thread = new Thread (new ThreadStart (delegate {
+                        Program.Controller.AddNoteToFolder (folder_name, revision, note);
+                    }));
+
+                    thread.Start ();
+                }
+            }
+        }
     }
 }
